# Package semi-ate-plugins

This package provides the contract (hookspec) for plugins in the context of Semi-ATE. It is based on pluggy. The hook-specification has to be implemented by any plugin that shall be loaded by the semi-ate-spyder plugin.
